[Freeswitch-svn] [commit] r2890 - in freeswitch/trunk/libs/win32: . pcre

Freeswitch SVN mikej at freeswitch.org
Sat Sep 30 02:11:28 EDT 2006


Author: mikej
Date: Sat Sep 30 02:11:27 2006
New Revision: 2890

Removed:
   freeswitch/trunk/libs/win32/pcre/pcre.h
Modified:
   freeswitch/trunk/libs/win32/Download PCRE.vcproj
   freeswitch/trunk/libs/win32/pcre/config.h
   freeswitch/trunk/libs/win32/pcre/libpcre.vcproj
   freeswitch/trunk/libs/win32/pcre/pcre_chartables.c.vcproj

Log:
update to pcre 6.7 for windows build.

Modified: freeswitch/trunk/libs/win32/Download PCRE.vcproj
==============================================================================
--- freeswitch/trunk/libs/win32/Download PCRE.vcproj	(original)
+++ freeswitch/trunk/libs/win32/Download PCRE.vcproj	Sat Sep 30 02:11:27 2006
@@ -72,8 +72,8 @@
 				<Tool
 					Name="VCCustomBuildTool"
 					Description="Downloading PCRE."
-					CommandLine="if not exist &quot;$(ProjectDir)..\pcre-6.4&quot; cscript /nologo &quot;$(ProjectDir)util.vbs&quot; GetUnzip http://svn.freeswitch.org/downloads/libs/pcre-6.4.tar.gz &quot;$(ProjectDir)..&quot;&#x0D;&#x0A;"
-					Outputs="$(ProjectDir)..\pcre-6.4"
+					CommandLine="if not exist &quot;$(ProjectDir)..\pcre-6.7&quot; cscript /nologo &quot;$(ProjectDir)util.vbs&quot; GetUnzip http://svn.freeswitch.org/downloads/libs/pcre-6.7.tar.gz &quot;$(ProjectDir)..&quot;&#x0D;&#x0A;"
+					Outputs="$(ProjectDir)..\pcre-6.7"
 				/>
 			</FileConfiguration>
 			<FileConfiguration
@@ -82,8 +82,8 @@
 				<Tool
 					Name="VCCustomBuildTool"
 					Description="Downloading PCRE."
-					CommandLine="if not exist &quot;$(ProjectDir)..\pcre-6.4&quot; cscript /nologo &quot;$(ProjectDir)util.vbs&quot; GetUnzip http://svn.freeswitch.org/downloads/libs/pcre-6.4.tar.gz &quot;$(ProjectDir)..&quot;&#x0D;&#x0A;"
-					Outputs="$(ProjectDir)..\pcre-6.4"
+					CommandLine="if not exist &quot;$(ProjectDir)..\pcre-6.7&quot; cscript /nologo &quot;$(ProjectDir)util.vbs&quot; GetUnzip http://svn.freeswitch.org/downloads/libs/pcre-6.7.tar.gz &quot;$(ProjectDir)..&quot;&#x0D;&#x0A;"
+					Outputs="$(ProjectDir)..\pcre-6.7"
 				/>
 			</FileConfiguration>
 		</File>

Modified: freeswitch/trunk/libs/win32/pcre/config.h
==============================================================================
--- freeswitch/trunk/libs/win32/pcre/libpcre.vcproj	(original)
+++ freeswitch/trunk/libs/win32/pcre/libpcre.vcproj	Sat Sep 30 02:11:27 2006
@@ -97,7 +97,7 @@
 			/>
 			<Tool
 				Name="VCPostBuildEventTool"
-				CommandLine="if not exist &quot;$(ProjectDir)..\..\include\&quot; md  &quot;$(ProjectDir)..\..\include\&quot;&#x0D;&#x0A;xcopy &quot;$(ProjectDir)pcre.h&quot; &quot;$(ProjectDir)..\..\include\&quot; /C /D /Y&#x0D;&#x0A;"
+				CommandLine="if not exist &quot;$(ProjectDir)..\..\include\&quot; md  &quot;$(ProjectDir)..\..\include\&quot;&#x0D;&#x0A;xcopy &quot;$(ProjectDir)..\..\pcre-6.7\pcre.h&quot; &quot;$(ProjectDir)..\..\include\&quot; /C /D /Y&#x0D;&#x0A;"
 			/>
 		</Configuration>
 		<Configuration
@@ -183,7 +183,7 @@
 			/>
 			<Tool
 				Name="VCPostBuildEventTool"
-				CommandLine="if not exist &quot;$(ProjectDir)..\..\include\&quot; md  &quot;$(ProjectDir)..\..\include\&quot;&#x0D;&#x0A;xcopy &quot;$(ProjectDir)pcre.h&quot; &quot;$(ProjectDir)..\..\include\&quot; /C /D /Y&#x0D;&#x0A;"
+				CommandLine="if not exist &quot;$(ProjectDir)..\..\include\&quot; md  &quot;$(ProjectDir)..\..\include\&quot;&#x0D;&#x0A;xcopy &quot;$(ProjectDir)..\..\pcre-6.7\pcre.h&quot; &quot;$(ProjectDir)..\..\include\&quot; /C /D /Y&#x0D;&#x0A;"
 			/>
 		</Configuration>
 		<Configuration
@@ -254,7 +254,7 @@
 				OutputFile="$(OutDir)\$(ProjectName).dll"
 				LinkIncremental="1"
 				SuppressStartupBanner="true"
-				ModuleDefinitionFile="$(InputDir)..\..\pcre-6.4\pcre.def"
+				ModuleDefinitionFile="$(InputDir)..\..\pcre-6.7\pcre.def"
 				GenerateDebugInformation="true"
 				ProgramDatabaseFile="$(IntDir)\$(ProjectName).pdb"
 				ImportLibrary="$(IntDir)\$(ProjectName).lib"
@@ -285,7 +285,7 @@
 			/>
 			<Tool
 				Name="VCPostBuildEventTool"
-				CommandLine="if not exist &quot;$(ProjectDir)..\..\include\&quot; md  &quot;$(ProjectDir)..\..\include\&quot;&#x0D;&#x0A;xcopy &quot;$(ProjectDir)pcre.h&quot; &quot;$(ProjectDir)..\..\include\&quot; /C /D /Y&#x0D;&#x0A;"
+				CommandLine="if not exist &quot;$(ProjectDir)..\..\include\&quot; md  &quot;$(ProjectDir)..\..\include\&quot;&#x0D;&#x0A;xcopy &quot;$(ProjectDir)..\..\pcre-6.7\pcre.h&quot; &quot;$(ProjectDir)..\..\include\&quot; /C /D /Y&#x0D;&#x0A;"
 			/>
 		</Configuration>
 		<Configuration
@@ -356,7 +356,7 @@
 				OutputFile="$(OutDir)\$(ProjectName).dll"
 				LinkIncremental="1"
 				SuppressStartupBanner="true"
-				ModuleDefinitionFile="$(InputDir)..\..\pcre-6.4\pcre.def"
+				ModuleDefinitionFile="$(InputDir)..\..\pcre-6.7\pcre.def"
 				ProgramDatabaseFile="$(IntDir)\$(ProjectName).pdb"
 				ImportLibrary="$(IntDir)\$(ProjectName).lib"
 				TargetMachine="1"
@@ -386,7 +386,7 @@
 			/>
 			<Tool
 				Name="VCPostBuildEventTool"
-				CommandLine="if not exist &quot;$(ProjectDir)..\..\include\&quot; md  &quot;$(ProjectDir)..\..\include\&quot;&#x0D;&#x0A;xcopy &quot;$(ProjectDir)pcre.h&quot; &quot;$(ProjectDir)..\..\include\&quot; /C /D /Y&#x0D;&#x0A;"
+				CommandLine="if not exist &quot;$(ProjectDir)..\..\include\&quot; md  &quot;$(ProjectDir)..\..\include\&quot;&#x0D;&#x0A;xcopy &quot;$(ProjectDir)..\..\pcre-6.7\pcre.h&quot; &quot;$(ProjectDir)..\..\include\&quot; /C /D /Y&#x0D;&#x0A;"
 			/>
 		</Configuration>
 	</Configurations>
@@ -402,11 +402,11 @@
 				>
 			</File>
 			<File
-				RelativePath="..\..\pcre-6.4\pcre_compile.c"
+				RelativePath="..\..\pcre-6.7\pcre_compile.c"
 				>
 			</File>
 			<File
-				RelativePath="..\..\pcre-6.4\pcre_config.c"
+				RelativePath="..\..\pcre-6.7\pcre_config.c"
 				>
 				<FileConfiguration
 					Name="Debug|Win32"
@@ -446,7 +446,7 @@
 				</FileConfiguration>
 			</File>
 			<File
-				RelativePath="..\..\pcre-6.4\pcre_dfa_exec.c"
+				RelativePath="..\..\pcre-6.7\pcre_dfa_exec.c"
 				>
 				<FileConfiguration
 					Name="Debug|Win32"
@@ -486,7 +486,7 @@
 				</FileConfiguration>
 			</File>
 			<File
-				RelativePath="..\..\pcre-6.4\pcre_exec.c"
+				RelativePath="..\..\pcre-6.7\pcre_exec.c"
 				>
 				<FileConfiguration
 					Name="Debug|Win32"
@@ -526,7 +526,7 @@
 				</FileConfiguration>
 			</File>
 			<File
-				RelativePath="..\..\pcre-6.4\pcre_fullinfo.c"
+				RelativePath="..\..\pcre-6.7\pcre_fullinfo.c"
 				>
 				<FileConfiguration
 					Name="Debug|Win32"
@@ -566,7 +566,7 @@
 				</FileConfiguration>
 			</File>
 			<File
-				RelativePath="..\..\pcre-6.4\pcre_get.c"
+				RelativePath="..\..\pcre-6.7\pcre_get.c"
 				>
 				<FileConfiguration
 					Name="Debug|Win32"
@@ -606,7 +606,7 @@
 				</FileConfiguration>
 			</File>
 			<File
-				RelativePath="..\..\pcre-6.4\pcre_globals.c"
+				RelativePath="..\..\pcre-6.7\pcre_globals.c"
 				>
 				<FileConfiguration
 					Name="Debug|Win32"
@@ -646,7 +646,7 @@
 				</FileConfiguration>
 			</File>
 			<File
-				RelativePath="..\..\pcre-6.4\pcre_info.c"
+				RelativePath="..\..\pcre-6.7\pcre_info.c"
 				>
 				<FileConfiguration
 					Name="Debug|Win32"
@@ -686,7 +686,7 @@
 				</FileConfiguration>
 			</File>
 			<File
-				RelativePath="..\..\pcre-6.4\pcre_maketables.c"
+				RelativePath="..\..\pcre-6.7\pcre_maketables.c"
 				>
 				<FileConfiguration
 					Name="Debug|Win32"
@@ -726,7 +726,7 @@
 				</FileConfiguration>
 			</File>
 			<File
-				RelativePath="..\..\pcre-6.4\pcre_ord2utf8.c"
+				RelativePath="..\..\pcre-6.7\pcre_ord2utf8.c"
 				>
 				<FileConfiguration
 					Name="Debug|Win32"
@@ -766,7 +766,7 @@
 				</FileConfiguration>
 			</File>
 			<File
-				RelativePath="..\..\pcre-6.4\pcre_refcount.c"
+				RelativePath="..\..\pcre-6.7\pcre_refcount.c"
 				>
 				<FileConfiguration
 					Name="Debug|Win32"
@@ -806,7 +806,7 @@
 				</FileConfiguration>
 			</File>
 			<File
-				RelativePath="..\..\pcre-6.4\pcre_study.c"
+				RelativePath="..\..\pcre-6.7\pcre_study.c"
 				>
 				<FileConfiguration
 					Name="Debug|Win32"
@@ -846,7 +846,7 @@
 				</FileConfiguration>
 			</File>
 			<File
-				RelativePath="..\..\pcre-6.4\pcre_tables.c"
+				RelativePath="..\..\pcre-6.7\pcre_tables.c"
 				>
 				<FileConfiguration
 					Name="Debug|Win32"
@@ -886,7 +886,7 @@
 				</FileConfiguration>
 			</File>
 			<File
-				RelativePath="..\..\pcre-6.4\pcre_try_flipped.c"
+				RelativePath="..\..\pcre-6.7\pcre_try_flipped.c"
 				>
 				<FileConfiguration
 					Name="Debug|Win32"
@@ -926,47 +926,11 @@
 				</FileConfiguration>
 			</File>
 			<File
-				RelativePath="..\..\pcre-6.4\pcre_ucp_findchar.c"
+				RelativePath="..\..\pcre-6.7\pcre_ucp_searchfuncs.c"
 				>
-				<FileConfiguration
-					Name="Debug|Win32"
-					>
-					<Tool
-						Name="VCCLCompilerTool"
-						AdditionalIncludeDirectories=""
-						PreprocessorDefinitions="_WIN32;WIN32;_DEBUG;_WINDOWS;_USRDLL;LIBPCRE_EXPORTS;SUPPORT_UTF8;SUPPORT_UCP;POSIX_MALLOC_THRESHOLD=10;NO_RECURSE;$(NoInherit)"
-					/>
-				</FileConfiguration>
-				<FileConfiguration
-					Name="Release|Win32"
-					>
-					<Tool
-						Name="VCCLCompilerTool"
-						AdditionalIncludeDirectories=""
-						PreprocessorDefinitions="_WIN32;WIN32;NDEBUG;_WINDOWS;_USRDLL;LIBPCRE_EXPORTS;SUPPORT_UTF8;SUPPORT_UCP;POSIX_MALLOC_THRESHOLD=10;NO_RECURSE;$(NoInherit)"
-					/>
-				</FileConfiguration>
-				<FileConfiguration
-					Name="Debug DLL|Win32"
-					>
-					<Tool
-						Name="VCCLCompilerTool"
-						AdditionalIncludeDirectories=""
-						PreprocessorDefinitions="_WIN32;WIN32;_DEBUG;_WINDOWS;_USRDLL;LIBPCRE_EXPORTS;SUPPORT_UTF8;SUPPORT_UCP;POSIX_MALLOC_THRESHOLD=10;NO_RECURSE;$(NoInherit)"
-					/>
-				</FileConfiguration>
-				<FileConfiguration
-					Name="Release DLL|Win32"
-					>
-					<Tool
-						Name="VCCLCompilerTool"
-						AdditionalIncludeDirectories=""
-						PreprocessorDefinitions="_WIN32;WIN32;NDEBUG;_WINDOWS;_USRDLL;LIBPCRE_EXPORTS;SUPPORT_UTF8;SUPPORT_UCP;POSIX_MALLOC_THRESHOLD=10;NO_RECURSE;$(NoInherit)"
-					/>
-				</FileConfiguration>
 			</File>
 			<File
-				RelativePath="..\..\pcre-6.4\pcre_valid_utf8.c"
+				RelativePath="..\..\pcre-6.7\pcre_valid_utf8.c"
 				>
 				<FileConfiguration
 					Name="Debug|Win32"
@@ -1006,7 +970,7 @@
 				</FileConfiguration>
 			</File>
 			<File
-				RelativePath="..\..\pcre-6.4\pcre_version.c"
+				RelativePath="..\..\pcre-6.7\pcre_version.c"
 				>
 				<FileConfiguration
 					Name="Debug|Win32"
@@ -1046,7 +1010,7 @@
 				</FileConfiguration>
 			</File>
 			<File
-				RelativePath="..\..\pcre-6.4\pcre_xclass.c"
+				RelativePath="..\..\pcre-6.7\pcre_xclass.c"
 				>
 				<FileConfiguration
 					Name="Debug|Win32"
@@ -1086,7 +1050,7 @@
 				</FileConfiguration>
 			</File>
 			<File
-				RelativePath="..\..\pcre-6.4\pcreposix.c"
+				RelativePath="..\..\pcre-6.7\pcreposix.c"
 				>
 				<FileConfiguration
 					Name="Debug|Win32"
@@ -1135,7 +1099,7 @@
 				>
 			</File>
 			<File
-				RelativePath="..\..\pcre-6.4\internal.h"
+				RelativePath="..\..\pcre-6.7\internal.h"
 				>
 			</File>
 			<File
@@ -1143,11 +1107,11 @@
 				>
 			</File>
 			<File
-				RelativePath="..\..\pcre-6.4\pcre_internal.h"
+				RelativePath="..\..\pcre-6.7\pcre_internal.h"
 				>
 			</File>
 			<File
-				RelativePath="..\..\pcre-6.4\pcreposix.h"
+				RelativePath="..\..\pcre-6.7\pcreposix.h"
 				>
 			</File>
 		</Filter>

Modified: freeswitch/trunk/libs/win32/pcre/pcre_chartables.c.vcproj
==============================================================================
--- freeswitch/trunk/libs/win32/pcre/pcre_chartables.c.vcproj	(original)
+++ freeswitch/trunk/libs/win32/pcre/pcre_chartables.c.vcproj	Sat Sep 30 02:11:27 2006
@@ -41,7 +41,7 @@
 			<Tool
 				Name="VCCLCompilerTool"
 				Optimization="0"
-				AdditionalIncludeDirectories="..\..\pcre-6.4\"
+				AdditionalIncludeDirectories="..\..\pcre-6.7\"
 				PreprocessorDefinitions="WIN32;_DEBUG;_CONSOLE;_CRT_SECURE_NO_DEPRECATE"
 				MinimalRebuild="true"
 				BasicRuntimeChecks="3"
@@ -120,7 +120,7 @@
 			/>
 			<Tool
 				Name="VCCLCompilerTool"
-				AdditionalIncludeDirectories="..\..\pcre-6.4\"
+				AdditionalIncludeDirectories="..\..\pcre-6.7\"
 				PreprocessorDefinitions="WIN32;NDEBUG;_CONSOLE;_CRT_SECURE_NO_DEPRECATE"
 				RuntimeLibrary="2"
 				UsePrecompiledHeader="0"



More information about the Freeswitch-svn mailing list
--- freeswitch/trunk/libs/win32/pcre/config.h	(original)
+++ freeswitch/trunk/libs/win32/pcre/config.h	Sat Sep 30 02:11:27 2006
@@ -1,16 +1,16 @@
-/* config.h.  Generated by configure.  */
 
-/* On Unix systems config.in is converted by configure into config.h. PCRE is
-written in Standard C, but there are a few non-standard things it can cope
-with, allowing it to run on SunOS4 and other "close to standard" systems.
+/* On Unix-like systems config.in is converted by "configure" into config.h.
+Some other environments also support the use of "configure". PCRE is written in
+Standard C, but there are a few non-standard things it can cope with, allowing
+it to run on SunOS4 and other "close to standard" systems.
 
-On a non-Unix system you should just copy this file into config.h, and set up
-the macros the way you need them. You should normally change the definitions of
-HAVE_STRERROR and HAVE_MEMMOVE to 1. Unfortunately, because of the way autoconf
-works, these cannot be made the defaults. If your system has bcopy() and not
-memmove(), change the definition of HAVE_BCOPY instead of HAVE_MEMMOVE. If your
-system has neither bcopy() nor memmove(), leave them both as 0; an emulation
-function will be used. */
+On a non-Unix-like system you should just copy this file into config.h, and set
+up the macros the way you need them. You should normally change the definitions
+of HAVE_STRERROR and HAVE_MEMMOVE to 1. Unfortunately, because of the way
+autoconf works, these cannot be made the defaults. If your system has bcopy()
+and not memmove(), change the definition of HAVE_BCOPY instead of HAVE_MEMMOVE.
+If your system has neither bcopy() nor memmove(), leave them both as 0; an
+emulation function will be used. */
 
 /* If you are compiling for a system that uses EBCDIC instead of ASCII
 character codes, define this macro as 1. On systems that can use "configure",
@@ -20,25 +20,31 @@
 #define EBCDIC 0
 #endif
 
-/* If you are compiling for a system that needs some magic to be inserted
-before the definition of an exported function, define this macro to contain the
-relevant magic. It apears at the start of every exported function. */
+/* If you are compiling for a system other than a Unix-like system or Win32,
+and it needs some magic to be inserted before the definition of a function that
+is exported by the library, define this macro to contain the relevant magic. If
+you do not define this macro, it defaults to "extern" for a C compiler and
+"extern C" for a C++ compiler on non-Win32 systems. This macro apears at the
+start of every exported function that is part of the external API. It does not
+appear on functions that are "external" in the C sense, but which are internal
+to the library. */
 
-#define PCRE_EXPORT
+/* #define PCRE_DATA_SCOPE */
 
-/* Define to empty if the keyword does not work. */
+/* Define the following macro to empty if the "const" keyword does not work. */
 
 /* #undef const */
 
-/* Define to `unsigned' if <stddef.h> doesn't define size_t. */
+/* Define the following macro to "unsigned" if <stddef.h> does not define
+size_t. */
 
 /* #undef size_t */
 
 /* The following two definitions are mainly for the benefit of SunOS4, which
-doesn't have the strerror() or memmove() functions that should be present in
+does not have the strerror() or memmove() functions that should be present in
 all Standard C libraries. The macros HAVE_STRERROR and HAVE_MEMMOVE should
 normally be defined with the value 1 for other systems, but unfortunately we
-can't make this the default because "configure" files generated by autoconf
+cannot make this the default because "configure" files generated by autoconf
 will only change 0 to 1; they won't change 1 to 0 if the functions are not
 found. */
 
@@ -46,51 +52,39 @@
 #define HAVE_MEMMOVE 1
 #define HAVE_WIN32API 1
 
-/* There are some non-Unix systems that don't even have bcopy(). If this macro
-is false, an emulation is used. If HAVE_MEMMOVE is set to 1, the value of
+/* There are some non-Unix-like systems that don't even have bcopy(). If this
+macro is false, an emulation is used. If HAVE_MEMMOVE is set to 1, the value of
 HAVE_BCOPY is not relevant. */
 
 #define HAVE_BCOPY 1
 
 /* The value of NEWLINE determines the newline character. The default is to
 leave it up to the compiler, but some sites want to force a particular value.
-On Unix systems, "configure" can be used to override this default. */
+On Unix-like systems, "configure" can be used to override this default. */
 
 #ifndef NEWLINE
 #define NEWLINE '\n'
 #endif
 
-/* The value of LINK_SIZE determines the number of bytes used to store
-links as offsets within the compiled regex. The default is 2, which allows for
-compiled patterns up to 64K long. This covers the vast majority of cases.
-However, PCRE can also be compiled to use 3 or 4 bytes instead. This allows for
-longer patterns in extreme cases. On Unix systems, "configure" can be used to
-override this default. */
+/* The value of LINK_SIZE determines the number of bytes used to store links as
+offsets within the compiled regex. The default is 2, which allows for compiled
+patterns up to 64K long. This covers the vast majority of cases. However, PCRE
+can also be compiled to use 3 or 4 bytes instead. This allows for longer
+patterns in extreme cases. On systems that support it, "configure" can be used
+to override this default. */
 
 #ifndef LINK_SIZE
 #define LINK_SIZE   2
 #endif
 
-/* The value of MATCH_LIMIT determines the default number of times the match()
-function can be called during a single execution of pcre_exec(). (There is a
-runtime method of setting a different limit.) The limit exists in order to
-catch runaway regular expressions that take for ever to determine that they do
-not match. The default is set very large so that it does not accidentally catch
-legitimate cases. On Unix systems, "configure" can be used to override this
-default default. */
-
-#ifndef MATCH_LIMIT
-#define MATCH_LIMIT 10000000
-#endif
-
 /* When calling PCRE via the POSIX interface, additional working storage is
 required for holding the pointers to capturing substrings because PCRE requires
 three integers per substring, whereas the POSIX interface provides only two. If
 the number of expected substrings is small, the wrapper function uses space on
 the stack, because this is faster than using malloc() for each call. The
-threshold above which the stack is no longer use is defined by POSIX_MALLOC_
-THRESHOLD. On Unix systems, "configure" can be used to override this default.
-*/
+threshold above which the stack is no longer used is defined by POSIX_MALLOC_
+THRESHOLD. On systems that support it, "configure" can be used to override this
+default. */
 
 #ifndef POSIX_MALLOC_THRESHOLD
 #define POSIX_MALLOC_THRESHOLD 10
@@ -99,13 +93,54 @@
 /* PCRE uses recursive function calls to handle backtracking while matching.
 This can sometimes be a problem on systems that have stacks of limited size.
 Define NO_RECURSE to get a version that doesn't use recursion in the match()
-function; instead it creates its own stack by steam using pcre_recurse_malloc
-to get memory. For more detail, see comments and other stuff just above the
-match() function. On Unix systems, "configure" can be used to set this in the
-Makefile (use --disable-stack-for-recursion). */
+function; instead it creates its own stack by steam using pcre_recurse_malloc()
+to obtain memory from the heap. For more detail, see the comments and other
+stuff just above the match() function. On systems that support it, "configure"
+can be used to set this in the Makefile (use --disable-stack-for-recursion). */
 
 /* #define NO_RECURSE */
 
+/* The value of MATCH_LIMIT determines the default number of times the internal
+match() function can be called during a single execution of pcre_exec(). There
+is a runtime interface for setting a different limit. The limit exists in order
+to catch runaway regular expressions that take for ever to determine that they
+do not match. The default is set very large so that it does not accidentally
+catch legitimate cases. On systems that support it, "configure" can be used to
+override this default default. */
+
+#ifndef MATCH_LIMIT
+#define MATCH_LIMIT 10000000
+#endif
+
+/* The above limit applies to all calls of match(), whether or not they
+increase the recursion depth. In some environments it is desirable to limit the
+depth of recursive calls of match() more strictly, in order to restrict the
+maximum amount of stack (or heap, if NO_RECURSE is defined) that is used. The
+value of MATCH_LIMIT_RECURSION applies only to recursive calls of match(). To
+have any useful effect, it must be less than the value of MATCH_LIMIT. There is
+a runtime method for setting a different limit. On systems that support it,
+"configure" can be used to override this default default. */
+
+#ifndef MATCH_LIMIT_RECURSION
+#define MATCH_LIMIT_RECURSION MATCH_LIMIT
+#endif
+
+/* These three limits are parameterized just in case anybody ever wants to
+change them. Care must be taken if they are increased, because they guard
+against integer overflow caused by enormously large patterns. */
+
+#ifndef MAX_NAME_SIZE
+#define MAX_NAME_SIZE 32
+#endif
+
+#ifndef MAX_NAME_COUNT
+#define MAX_NAME_COUNT 10000
+#endif
+
+#ifndef MAX_DUPLENGTH
+#define MAX_DUPLENGTH 30000
+#endif
+
 #ifndef INVALID_FILE_ATTRIBUTES
 #define INVALID_FILE_ATTRIBUTES (-1L)
 #endif
@@ -119,7 +154,6 @@
 #endif
 #endif // VC8+
 
-#pragma warning(disable: 4005)
-
+#pragma warning(disable: 4005 4003 4018)
 
 /* End */

Modified: freeswitch/trunk/libs/win32/pcre/libpcre.vcproj
==============================================================================